Struct google_cloudiot1::SendCommandToDeviceResponse [−][src]
pub struct SendCommandToDeviceResponse { /* fields omitted */ }Response for SendCommandToDevice.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).