Struct google_cloudiot1::SendCommandToDeviceRequest [−][src]
pub struct SendCommandToDeviceRequest {
pub binary_data: Option<String>,
pub subfolder: Option<String>,
}Request for SendCommandToDevice.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
binary_data: Option<String>
The command data to send to the device.
subfolder: Option<String>
Optional subfolder for the command. If empty, the command will be delivered to the /devices/{device-id}/commands topic, otherwise it will be delivered to the /devices/{device-id}/commands/{subfolder} topic. Multi-level subfolders are allowed. This field must not have more than 256 characters, and must not contain any MQTT wildcards ("+" or "#") or null characters.